==> nextcloud-29.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/hu.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Engedélyezte a TOTP kétlépcsős hitelesítést a fiókjához",
    "You disabled TOTP two-factor authentication for your account" : "Letiltotta a TOTP kétlépcsős hitelesítést a fiókjához",
    "TOTP two-factor authentication disabled by an admin" : "A TOTP kétlépcsős hitelesítést egy rendszergazda letiltotta",
    "TOTP (Authenticator app)" : "TOTP (Hitelesítő alkalmazás)",
    "Authenticate with a TOTP app" : "Hitelesítés egy TOTP alkalmazással",
    "Two-Factor TOTP Provider" : "Kétlépcsős TOTP szolgáltató",
    "TOTP two-factor provider" : "TOTP kétlépcsős szolgáltató",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Kétlépcsős hitelesítésszolgáltató TOTP-hez (RFC6238)",
    "Enable TOTP" : "Időalapú egyszer használatos jelszó (TOTP) engedélyezése",
    "Could not enable TOTP" : "Nem sikerült engedélyezni a TOTP-t",
    "Could not verify your key. Please try again" : "A kulcs nem ellenőrizhető. Próbálja meg újra.",
    "Your new TOTP secret is:" : "Az új TOTP titka:",
    "For quick setup, scan this QR code with your TOTP app:" : "A gyors beállításhoz olvassa be ezt a QR-kódot a TOTP alkalmazásával:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Miután beállította az alkalmazást, írja be az alábbi tesztkódot, hogy meggyőződhessen arról, hogy minden megfelelően működik:",
    "Authentication code" : "Hitelesítőkód",
    "Verify" : "Ellenőrzés",
    "Get the authentication code from the two-factor authentication app on your device." : "Szerezze meg a hitelesítőkódot az eszközén lévő kétlépcsős hitelesítési alkalmazásából.",
    "Submit" : "Küldés"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/hu.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Engedélyezte a TOTP kétlépcsős hitelesítést a fiókjához",
    "You disabled TOTP two-factor authentication for your account" : "Letiltotta a TOTP kétlépcsős hitelesítést a fiókjához",
    "TOTP (Authenticator app)" : "TOTP (Hitelesítő alkalmazás)",
    "Authenticate with a TOTP app" : "Hitelesítés egy TOTP alkalmazással",
    "Two-Factor TOTP Provider" : "Kétlépcsős TOTP szolgáltató",
    "Enable TOTP" : "Időalapú egyszer használatos jelszó (TOTP) engedélyezése",
    "Could not enable TOTP" : "Nem sikerült engedélyezni a TOTP-t",
    "Could not verify your key. Please try again" : "A kulcs nem ellenőrizhető. Próbálja meg újra.",
    "Your new TOTP secret is:" : "Az új TOTP titka:",
    "For quick setup, scan this QR code with your TOTP app:" : "A gyors beállításhoz olvassa be ezt a QR-kódot a TOTP alkalmazásával:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Miután beállította az alkalmazást, írja be az alábbi tesztkódot, hogy meggyőződhessen arról, hogy minden megfelelően működik:",
    "Authentication code" : "Hitelesítőkód",
    "Verify" : "Ellenőrzés",
    "Get the authentication code from the two-factor authentication app on your device." : "Szerezze meg a hitelesítőkódot az eszközén lévő kétlépcsős hitelesítési alkalmazásából.",
    "Submit" : "Küldés",
    "TOTP two-factor authentication disabled by an admin" : "A TOTP kétlépcsős hitelesítést egy rendszergazda letiltotta",
    "TOTP two-factor provider" : "TOTP kétlépcsős szolgáltató",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Kétlépcsős hitelesítésszolgáltató TOTP-hez (RFC6238)"
},
"nplurals=2; plural=(n != 1);");
